@@ -19,7 +19,7 @@ import pickle  # noqa
 from .background import ScatteredLightBackground  # noqa
 from .cupy_numpy_imports import load_image  # noqa
 from .scene import StarScene  # noqa
-from .tpf import correct_tpf  # noqa
+from .tpf import *  # noqa
 from .version import __version__  # noqa
 
 sector_times = pickle.load(open(f"{PACKAGEDIR}/data/tess_sector_times.pkl", "rb"))
