@@ -170,7 +170,7 @@ class StarScene:
     def path(self):
         return (
             f"{PACKAGEDIR}/data/sector{self.sector:03}/camera{self.camera:02}/ccd{self.ccd:02}/"
-            f"tessstarscene_sector{self.sector}_camera{self.camera}_ccd{self.ccd}.fits.gz"
+            f"tessstarscene_sector{self.sector}_camera{self.camera}_ccd{self.ccd}.fits"
         )
 
     def __getitem__(self, key):
@@ -192,7 +192,7 @@ class StarScene:
         return copy
 
     def _get_spline_design_matrix(
-        self, mask=None, ncomps=20, degree=2, nknots=20, bounds=(-0.5, 0.5)
+        self, mask=None, ncomps=10, degree=2, nknots=20, bounds=(-0.5, 0.5)
     ):
         """Construct a design matrix from the ScatteredLightBackground object"""
         if mask is None:
@@ -250,7 +250,7 @@ class StarScene:
     @staticmethod
     def exists(sector=None, camera=None, ccd=None, dir=None):
         for type in ["backdrop", "starscene"]:
-            fname = f"tess{type}_sector{sector}_camera{camera}_ccd{ccd}.fits.gz"
+            fname = f"tess{type}_sector{sector}_camera{camera}_ccd{ccd}.fits"
             if dir is None:
                 dir = f"{PACKAGEDIR}/data/sector{sector:03}/camera{camera:02}/ccd{ccd:02}/"
             if dir != "":
@@ -327,9 +327,10 @@ class StarScene:
 
         [[mininmum row, maxmimum row], [minimum column, maximum column]]
         """
-        return get_locs(2048, 512)
+        return get_locs(2048, self.batch_size)
 
-    def load(self, input, dir=None):
+    @staticmethod
+    def from_disk(sector, camera, ccd, row=None, column=None, dir=None):
         """
         Load a model fit from the data directory.
 
@@ -345,29 +346,32 @@ class StarScene:
         -------
         self: `scatterbrain.StarScene` object
         """
-        if isinstance(input, tuple):
-            if len(input) == 3:
-                sector, camera, ccd = input
-                fname = f"tessstarscene_sector{sector}_camera{camera}_ccd{ccd}.fits"
-            else:
-                raise ValueError("Please pass tuple as `(sector, camera, ccd)`")
-        elif isinstance(input, str):
-            fname = input
-        else:
-            raise ValueError("Can not parse input")
+        fname = f"tessstarscene_sector{sector}_camera{camera}_ccd{ccd}.fits"
         if dir is None:
             dir = f"{PACKAGEDIR}/data/sector{sector:03}/camera{camera:02}/ccd{ccd:02}/"
         if dir != "":
             if not os.path.isdir(dir):
                 raise ValueError("No solutions exist")
         log.debug(f"Loading StarScene from {dir+fname}")
-        with fits.open(dir + fname, lazy_load_hdus=True) as hdu:
-            for key in [
-                "sector",
-                "camera",
-                "ccd",
-            ]:
-                setattr(self, key, hdu[0].header[key])
+        return StarScene.from_path(dir + fname, row=row, column=column)
+
+    @staticmethod
+    def from_path(path, row=None, column=None):
+        if row is None:
+            row = np.asarray([1])
+        if column is None:
+            column = np.asarray([1])
+        with fits.open(path, lazy_load_hdus=True) as hdu:
+            sector, camera, ccd = [
+                hdu[0].header[key]
+                for key in [
+                    "sector",
+                    "camera",
+                    "ccd",
+                ]
+            ]
+        self = StarScene(sector=sector, camera=camera, ccd=ccd, row=row, column=column)
+        with fits.open(path, lazy_load_hdus=True) as hdu:
             setattr(self, "batch_size", hdu[0].header["BATSIZE"])
             if "NCOMPS" in hdu[0].header:
                 setattr(self, "ncomps", hdu[0].header["NCOMPS"])
@@ -377,34 +381,23 @@ class StarScene:
         self.weight_row = np.arange(self.row[0], self.row[-1] + 1)
         self.weight_column = np.arange(self.column[0], self.column[-1] + 1)
         self.weights = [
-            fitsio.FITS(dir + fname)[1][
+            fitsio.FITS(path)[1][
                 :, self.row[0] : self.row[-1] + 1, self.column[0] : self.column[-1] + 1
             ],
-            fitsio.FITS(dir + fname)[2][
+            fitsio.FITS(path)[2][
                 :, self.row[0] : self.row[-1] + 1, self.column[0] : self.column[-1] + 1
             ],
         ]
         self.bad_pixels = [
-            fitsio.FITS(dir + fname)[3][
+            fitsio.FITS(path)[3][
                 self.row[0] : self.row[-1] + 1, self.column[0] : self.column[-1] + 1
             ].astype(bool),
-            fitsio.FITS(dir + fname)[4][
+            fitsio.FITS(path)[4][
                 self.row[0] : self.row[-1] + 1, self.column[0] : self.column[-1] + 1
             ].astype(bool),
         ]
         return self
 
-    @staticmethod
-    def from_disk(sector, camera, ccd, dir=None, row=None, column=None):
-        return StarScene(
-            sector=sector,
-            camera=camera,
-            ccd=ccd,
-            batch_size=512,
-            row=row,
-            column=column,
-        ).load((sector, camera, ccd), dir=dir)
-
     def _package_weights_hdulist(self):
         hdu0 = self.hdu0
         hdu1 = fits.ImageHDU(np.asarray(self.weights[0]), name="ORBIT1")
@@ -439,10 +432,6 @@ class StarScene:
         log.debug(f"Saving to {fname}")
         hdul.writeto(output_dir + fname, overwrite=overwrite)
         log.debug("Saved")
-        if os.path.isfile(output_dir + fname + ".gz"):
-            os.remove(f"{output_dir + fname}.gz")
-        os.system(f"gzip {output_dir + fname}")
-        log.debug("Compressed")
         return
 
     def get_images(self, fnames, loc, orbit=1):
